@@ -112,6 +112,7 @@ public:
         virtual void onFrameAvailable(const QVideoFrame &frame) = 0;
     };
     void setPreviewCallback(PreviewCallback *callback);
+    bool requestRecordingPermission();
 
 Q_SIGNALS:
     void statusChanged(QCamera::Status status);
@@ -165,6 +166,8 @@ private:
     static QVideoFrame::PixelFormat QtPixelFormatFromAndroidImageFormat(AndroidCamera::ImageFormat);
     static AndroidCamera::ImageFormat AndroidImageFormatFromQtPixelFormat(QVideoFrame::PixelFormat);
 
+    void setStateHelper(QCamera::State state);
+
     int m_selectedCamera;
     AndroidCamera *m_camera;
     int m_nativeOrientation;
@@ -194,6 +197,7 @@ private:
     QSet<QAndroidMediaVideoProbeControl *> m_videoProbes;
     QMutex m_videoProbesMutex;
     PreviewCallback *m_previewCallback;
+    bool m_keepActive;
 };
 
 QT_END_NAMESPACE
